@@ -1,11 +1,14 @@
 from datetime import date, time, timedelta
 import json
 
+import math
 import pandas as pd
 import pytest
 
 import httpretty
 
+from pandas.testing import assert_frame_equal
+
 from swiftly_api_client import (
     SwiftlyAPIClient,
     SwiftlyAPIClientError,
@@ -289,6 +292,66 @@ def test_get_on_time_performance_export():
     assert sent_req.querystring["route"] == ["NC2010"]
 
 
+@httpretty.activate
+def test_get_trip_observations_export_single_vehicles():
+    agency = "test_agency"
+    target_date = date(2023, 6, 30)
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    path = f"/run-times/{agency}/trip-observations"
+    url = SwiftlyAPIClient.PROD_BASE_URL + path
+
+    httpretty.register_uri(
+        httpretty.GET,
+        url,
+        responses=[
+            httpretty.Response(
+                body="""blockId,tripId,tripShortName,routeShortName,routeId,directionId,serviceId,tripPatternId,scheduledTripStartTime,serviceDate,observedTripStartTime,observedTripEndTime,secondsToNextTripInBlockScheduledStartTime,scheduledRuntimeSeconds,numScheduledStopsOnTrip,numStopsWithArrivalDepartureData,isCompleteTrip,totalStopPathLength,observedDwellSeconds,observedTravelSeconds,observedRuntimeSeconds,driverIds,vehicleIds,scheduleRelationship,adjustmentIds,adjustmentTypes
+503-1,t_5561882_b_80157_tn_1,t_5561882_b_80157_tn_1,503,503,1,c_69241_b_80157_d_31,route_503_2561389_to_2561195_9e652c333c004f1edb920350d153a6f53514f9e293ed5cb3a473a51241a1f50d,05:30:00,2023-06-30,05:33:40,06:24:32,5400,3720,62,62,true,31085.13250732422,488.4921875,2563.963,3052.455,,2202,ADDED,,
+403-1,t_5561912_b_80157_tn_0,t_5561912_b_80157_tn_0,403,403,1,c_69241_b_80157_d_31,route_403_2561121_to_2561195_d9b545300a47a081ac76b4d278e8b2d085775ee0bd9a8f4529c0694b55e1dde3,05:37:00,2023-06-30,,05:55:59,1380,780,13,8,false,5809.577941894531,,,,,2203,SCHEDULED,,
+                """,
+                status=200,
+            ),
+        ],
+    )
+    df = client.get_trip_observations_export(start_date=target_date)
+
+    expected_df = pd.DataFrame(
+        {
+            "blockId": ["503-1", "403-1"],
+            "tripId": ["t_5561882_b_80157_tn_1", "t_5561912_b_80157_tn_0"],
+            "tripShortName": ["t_5561882_b_80157_tn_1", "t_5561912_b_80157_tn_0"],
+            "routeShortName": [503, 403],
+            "routeId": [503, 403],
+            "directionId": [1, 1],
+            "serviceId": ["c_69241_b_80157_d_31", "c_69241_b_80157_d_31"],
+            "tripPatternId": [
+                "route_503_2561389_to_2561195_9e652c333c004f1edb920350d153a6f53514f9e293ed5cb3a473a51241a1f50d",
+                "route_403_2561121_to_2561195_d9b545300a47a081ac76b4d278e8b2d085775ee0bd9a8f4529c0694b55e1dde3",
+            ],
+            "scheduledTripStartTime": ["05:30:00", "05:37:00"],
+            "serviceDate": ["2023-06-30", "2023-06-30"],
+            "observedTripStartTime": ["05:33:40", math.nan],
+            "observedTripEndTime": ["06:24:32", "05:55:59"],
+            "secondsToNextTripInBlockScheduledStartTime": [5400, 1380],
+            "scheduledRuntimeSeconds": [3720, 780],
+            "numScheduledStopsOnTrip": [62, 13],
+            "numStopsWithArrivalDepartureData": [62, 8],
+            "isCompleteTrip": [True, False],
+            "totalStopPathLength": [31085.13250732422, 5809.577941894531],
+            "observedDwellSeconds": [488.4921875, math.nan],
+            "observedTravelSeconds": [2563.963, math.nan],
+            "observedRuntimeSeconds": [3052.455, math.nan],
+            "driverIds": [math.nan, math.nan],
+            "vehicleIds": ["2202", "2203"],
+            "scheduleRelationship": ["ADDED", "SCHEDULED"],
+            "adjustmentIds": [math.nan, math.nan],
+            "adjustmentTypes": [math.nan, math.nan],
+        }
+    )
+    assert_frame_equal(df, expected_df)
+
+
 @httpretty.activate
 def test_get_trip_observations_export():
     agency = "test_agency"
@@ -330,6 +393,24 @@ def test_get_trip_observations_export():
             == "CANCELED"
         )
 
+        breakpoint()
+        assert math.isnan(
+            df[df["tripId"] == "t_5561911_b_80157_tn_0"].iloc[0].vehicleIds
+        )
+        assert df[df["tripId"] == "t_5561882_b_80157_tn_1"].iloc[0].vehicleIds == "2202"
+        assert (
+            df[df["tripId"] == "t_5561916_b_80157_tn_0"].iloc[0].vehicleIds
+            == "2201,2205"
+        )
+        assert df[df["tripId"] == "t_5561912_b_80157_tn_0"].iloc[0].vehicleIds == "2203"
+
+        assert math.isnan(
+            df[df["tripId"] == "t_5561823_b_80157_tn_0"].iloc[0].vehicleIds
+        )
+        assert math.isnan(
+            df[df["tripId"] == "t_5561915_b_80157_tn_11"].iloc[0].vehicleIds
+        )
+
     sent_req = httpretty.last_request()
     assert sent_req.querystring["startDate"] == ["06-30-2023"]
     assert sent_req.querystring["endDate"] == ["06-30-2023"]
